<?php
/**
 * Fired during plugin activation
 *
 * @link       https://club.wpeka.com
 * @since      1.0
 *
 * @package    Gdpr_Cookie_Consent
 * @subpackage Gdpr_Cookie_Consent/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0
 * @package    Gdpr_Cookie_Consent
 * @subpackage Gdpr_Cookie_Consent/includes
 * @author     wpeka <https://club.wpeka.com>
 */
class Gdpr_Cookie_Consent_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0
	 */
	public static function activate() {
		// previous version settings.
		$gdpr_option = get_option( 'GDPRCookieConsent-1.0' );
		$wpl_option  = get_option( 'WPLCookieConsent-1.0' );
		if ( isset( $gdpr_option['is_on'] ) ) {
			update_option( GDPR_COOKIE_CONSENT_SETTINGS_FIELD, $gdpr_option );
			delete_option( 'GDPRCookieConsent-1.0' );
		} elseif ( isset( $wpl_option['is_on'] ) ) {
			update_option( GDPR_COOKIE_CONSENT_SETTINGS_FIELD, $wpl_option );
			delete_option( 'WPLCookieConsent-1.0' );
		}
		$default_options = get_option( GDPR_COOKIE_CONSENT_SETTINGS_FIELD );
		if ( isset( $default_options['notify_div_id'] ) ) {
			$default_options['notify_div_id'] = '#gdpr-cookie-consent-bar';
			update_option( GDPR_COOKIE_CONSENT_SETTINGS_FIELD, $default_options );
		}
		// Update settings from Version 1.7.6.
		$prev_gdpr_option = get_option( 'GDPRCookieConsent-2.0' );
		if ( isset( $prev_gdpr_option['is_on'] ) ) {
			unset( $prev_gdpr_option['button_1_selected_text'] );
			$prev_gdpr_option['button_1_text']              = 'Accept';
			$prev_gdpr_option['notify_message']             = addslashes( 'This website uses cookies to improve your experience. We\'ll assume you\'re ok with this, but you can opt-out if you wish.' );
			$prev_gdpr_option['opacity']                    = '0.80';
			$prev_gdpr_option['template']                   = 'banner-default';
			$prev_gdpr_option['banner_template']            = 'banner-default';
			$prev_gdpr_option['popup_template']             = 'popup-default';
			$prev_gdpr_option['widget_template']            = 'widget-default';
			$prev_gdpr_option['button_1_is_on']             = true;
			$prev_gdpr_option['button_2_is_on']             = true;
			$prev_gdpr_option['button_3_is_on']             = true;
			$prev_gdpr_option['notify_position_horizontal'] = false;
			$prev_gdpr_option['bar_heading_text']           = 'This website uses cookies';

			$prev_gdpr_option['button_4_text']         = 'Cookie Settings';
			$prev_gdpr_option['button_4_url']          = '#';
			$prev_gdpr_option['button_4_action']       = '#cookie_action_settings';
			$prev_gdpr_option['button_4_link_color']   = '#fff';
			$prev_gdpr_option['button_4_button_color'] = '#333';
			$prev_gdpr_option['button_4_new_win']      = false;
			$prev_gdpr_option['button_4_as_button']    = true;
			$prev_gdpr_option['button_4_button_size']  = 'medium';
			$prev_gdpr_option['button_4_is_on']        = true;
			$prev_gdpr_option['button_4_as_popup']     = false;
			update_option( GDPR_COOKIE_CONSENT_SETTINGS_FIELD, $prev_gdpr_option );
			delete_option( 'GDPRCookieConsent-2.0' );
		}
		// Update settings from Version 1.7.9.
		$prev_gdpr_option = get_option( 'GDPRCookieConsent-3.0' );
		if ( isset( $prev_gdpr_option['is_on'] ) ) {
			$prev_gdpr_option['bar_heading_text']     = '';
			$prev_gdpr_option['show_again']           = true;
			$prev_gdpr_option['is_script_blocker_on'] = false;
			$prev_gdpr_option['auto_hide']            = false;
			$prev_gdpr_option['auto_scroll']          = false;
			$prev_gdpr_option['show_again_position']  = 'right';
			$prev_gdpr_option['show_again_text']      = 'Cookie Settings';
			$prev_gdpr_option['auto_hide_delay']      = '10000';
			$prev_gdpr_option['show_again_margin']    = '5%';
			$prev_gdpr_option['show_again_div_id']    = '#gdpr-cookie-consent-show-again';

			update_option( GDPR_COOKIE_CONSENT_SETTINGS_FIELD, $prev_gdpr_option );
			delete_option( 'GDPRCookieConsent-3.0' );
		}
	}

}
